@@ -267,10 +267,10 @@ WEBKIT_API void
 webkit_settings_set_enable_tabs_to_links                       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_dns_prefetching                     (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_dns_prefetching                     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -389,6 +389,13 @@ WEBKIT_DEPRECATED void
 webkit_settings_set_enable_accelerated_2d_canvas               (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
+WEBKIT_API gboolean
+webkit_settings_get_enable_2d_canvas_acceleration              (WebKitSettings *settings);
+
+WEBKIT_API void
+webkit_settings_set_enable_2d_canvas_acceleration              (WebKitSettings *settings,
+                                                                gboolean        enabled);
+
 WEBKIT_API gboolean
 webkit_settings_get_enable_write_console_messages_to_stdout    (WebKitSettings *settings);
 
@@ -535,6 +542,19 @@ webkit_settings_get_experimental_features                      (void);
 WEBKIT_API WebKitFeatureList *
 webkit_settings_get_development_features                       (void);
 
+WEBKIT_API gboolean
+webkit_settings_apply_from_key_file                            (WebKitSettings  *settings,
+                                                                GKeyFile        *key_file,
+                                                                const gchar     *group_name,
+                                                                GError         **error);
+
+WEBKIT_API const gchar*
+webkit_settings_get_webrtc_udp_ports_range                     (WebKitSettings *settings);
+
+WEBKIT_API void
+webkit_settings_set_webrtc_udp_ports_range                     (WebKitSettings *settings,
+                                                                const gchar    *udp_port_range);
+
 G_END_DECLS
 
 #endif /* WebKitSettings_h */
